@@ -1,12 +1,15 @@
 """Schedule a build for the given machine in CI/CD"""
 import argparse
+from typing import TextIO
 
 from rich.console import Console
 
 from gbpcli import GBP
 
 
-def handler(args: argparse.Namespace, gbp: GBP, _console: Console) -> int:
+def handler(
+    args: argparse.Namespace, gbp: GBP, _console: Console, _errorf: TextIO
+) -> int:
     """Schedule a build for the given machine in CI/CD"""
     gbp.build(args.machine)
 
