@@ -1,19 +1,21 @@
 """Display logs for the given build"""
 import argparse
-import sys
+from typing import TextIO
 
 from rich.console import Console
 
 from gbpcli import GBP, utils
 
 
-def handler(args: argparse.Namespace, gbp: GBP, console: Console) -> int:
+def handler(
+    args: argparse.Namespace, gbp: GBP, console: Console, errorf: TextIO
+) -> int:
     """Show build logs"""
-    build = utils.resolve_build_id(args.machine, args.number, gbp)
+    build = utils.resolve_build_id(args.machine, args.number, gbp, errorf=errorf)
     text = gbp.logs(build)
 
     if text is None:
-        print("Not Found", file=sys.stderr)
+        print("Not Found", file=errorf)
         return 1
 
     console.print(text)
