@@ -1,11 +1,12 @@
 """List machines with builds"""
 import argparse
+from typing import TextIO
 
 from rich import box
 from rich.console import Console
 from rich.table import Table
 
-from gbpcli import GBP
+from gbpcli import GBP, utils
 
 
 def latest_build_to_str(build: dict) -> str:
@@ -18,11 +19,21 @@ def latest_build_to_str(build: dict) -> str:
     return f"[build_id]{build_id}[/build_id]"
 
 
-def handler(_args: argparse.Namespace, gbp: GBP, console: Console) -> int:
+def handler(
+    args: argparse.Namespace, gbp: GBP, console: Console, _errorf: TextIO
+) -> int:
     """List machines with builds"""
-    machines = gbp.machines()
+    my_machines = utils.get_my_machines_from_args(args)
+    machines = [
+        machine
+        for machine in gbp.machines()
+        if not args.mine or machine[0] in my_machines
+    ]
     table = Table(
-        title=f"{len(machines)} Machines", box=box.ROUNDED, title_style="header"
+        title=f"{len(machines)} Machines",
+        box=box.ROUNDED,
+        title_style="header",
+        style="box",
     )
     table.add_column("Machine", header_style="header")
     table.add_column("Builds", justify="right", header_style="header")
@@ -30,7 +41,7 @@ def handler(_args: argparse.Namespace, gbp: GBP, console: Console) -> int:
 
     for machine, builds, latest in machines:
         table.add_row(
-            f"[machine]{machine}[/machine]",
+            utils.format_machine(machine, args),
             str(builds),
             latest_build_to_str(latest),
         )
@@ -39,5 +50,11 @@ def handler(_args: argparse.Namespace, gbp: GBP, console: Console) -> int:
     return 0
 
 
-def parse_args(_parser: argparse.ArgumentParser) -> None:
+def parse_args(parser: argparse.ArgumentParser) -> None:
     """Set subcommand arguments"""
+    parser.add_argument(
+        "--mine",
+        action="store_true",
+        default=False,
+        help="Only display machine info for --my-machines",
+    )
