@@ -1,19 +1,21 @@
 """Display the list of packages for a given build"""
 import argparse
-import sys
+from typing import TextIO
 
 from rich.console import Console
 
 from gbpcli import GBP, utils
 
 
-def handler(args: argparse.Namespace, gbp: GBP, console: Console) -> int:
+def handler(
+    args: argparse.Namespace, gbp: GBP, console: Console, errorf: TextIO
+) -> int:
     """List a build's packages"""
-    build = utils.resolve_build_id(args.machine, args.number, gbp)
+    build = utils.resolve_build_id(args.machine, args.number, gbp, errorf=errorf)
     packages = gbp.packages(build)
 
     if packages is None:
-        print("Not Found", file=sys.stderr)
+        print("Not Found", file=errorf)
         return 1
 
     for package in packages:
