@@ -3,6 +3,7 @@
 If NUMBER is not specified, defaults to the latest build for the given machine.
 """
 import argparse
+from typing import TextIO
 
 from rich.console import Console
 
@@ -10,9 +11,11 @@ from gbpcli import GBP
 from gbpcli.utils import resolve_build_id
 
 
-def handler(args: argparse.Namespace, gbp: GBP, _console: Console) -> int:
+def handler(
+    args: argparse.Namespace, gbp: GBP, _console: Console, errorf: TextIO
+) -> int:
     """Publish a build"""
-    build = resolve_build_id(args.machine, args.number, gbp)
+    build = resolve_build_id(args.machine, args.number, gbp, errorf=errorf)
 
     gbp.publish(build)
 
