@@ -1,9 +1,10 @@
 """Utility functions"""
+import argparse
 import datetime
 import io
 import sys
 from functools import partial
-from typing import Literal, Optional
+from typing import Literal, Optional, TextIO
 
 from gbpcli import GBP, LOCAL_TIMEZONE, Build
 
@@ -84,7 +85,11 @@ def build_to_str(build: Build) -> str:
 
 
 def resolve_build_id(
-    machine: str, build_id: Optional[str], gbp: GBP, abort_on_error: bool = True
+    machine: str,
+    build_id: Optional[str],
+    gbp: GBP,
+    abort_on_error: bool = True,
+    errorf: TextIO = sys.stderr,
 ) -> Build:
     """Resolve build ids, tags, and optional numbers into a Build object
 
@@ -97,21 +102,47 @@ def resolve_build_id(
     if build_id is None:
         build = gbp.latest(machine)
         if not build and abort_on_error:
-            print(f"No builds for {machine}", file=sys.stderr)
+            print(f"No builds for {machine}", file=errorf)
             raise error
     elif build_id.startswith(TAG_SYM):
         tag = build_id[1:]
         build = gbp.resolve_tag(machine, tag)
         if not build and abort_on_error:
-            print(f"No such tag for {machine}: {tag}", file=sys.stderr)
+            print(f"No such tag for {machine}: {tag}", file=errorf)
             raise error
     elif build_id.isdigit():
         build = Build(machine, int(build_id))
     elif abort_on_error:
-        print(f"Invalid build ID: {build_id}", file=sys.stderr)
+        print(f"Invalid build ID: {build_id}", file=errorf)
         raise error
 
     if build is None:
         raise ValueError(f"Invalid build ID: {build_id}")
 
     return build
+
+
+def get_my_machines_from_args(args: argparse.Namespace) -> list[str]:
+    """Return the list of "my machines" attached to parsed args
+
+    If There are no return an empty list.
+    """
+    try:
+        return args.my_machines.split()
+    except AttributeError:
+        return []
+
+
+def format_machine(machine: str, args: argparse.Namespace) -> str:
+    """Format the given machine name for rich output
+
+    If the given machine is given in the `my_machines` argument then it will have
+    special styling.
+    """
+    pre, post = "", ""
+
+    if machine in get_my_machines_from_args(args):
+        pre = "[mymachine]"
+        post = "[/mymachine]"
+
+    return f"[machine]{pre}{machine}{post}[/machine]"
