@@ -1,10 +1,13 @@
 """Tests for the GBP interface"""
 # pylint: disable=missing-docstring
+import os
+from unittest import mock
+
 import requests.exceptions
 
-from gbpcli import DEFAULT_THEME, Queries, get_colormap_from_string
+from gbpcli import DEFAULT_THEME, Queries, build_parser, get_colormap_from_string
 
-from . import TestCase, make_response, mock_print
+from . import TestCase, make_response
 
 
 class GBPQueryTestCase(TestCase):
@@ -35,7 +38,7 @@ class GBPQueryTestCase(TestCase):
 
         self.assertEqual(response, ({"foo": "bar"}, [{"this": "that"}]))
 
-    @mock_print("gbpcli")
+    @mock.patch("gbpcli.print")
     def test_exits_on_connection_errors(self, _):
         query = "query foo { bar }"
         self.gbp.session.post.side_effect = requests.exceptions.ConnectionError()
@@ -148,3 +151,39 @@ class GetColormapFromString(TestCase):
         self.assertEqual(result["header"], "test_header")
         self.assertEqual(result["note"], "test_note")
         self.assertFalse("unknown" in result)
+
+
+class BuildParserTestCase(TestCase):
+    """Tests for the build_parser method"""
+
+    def setUp(self):
+        super().setUp()
+
+        patch = mock.patch.dict(os.environ, clear=True)
+        self.addCleanup(patch.stop)
+        patch.start()
+
+    def test_my_machines_string(self):
+        argv = ["--my-machines", "this that the other"]
+
+        parser = build_parser()
+        args = parser.parse_args(argv)
+
+        self.assertEqual(args.my_machines, "this that the other")
+
+    def test_my_machines_not_passed(self):
+        argv = []
+
+        parser = build_parser()
+        args = parser.parse_args(argv)
+
+        self.assertEqual(args.my_machines, "")
+
+    def test_my_machines_from_environ(self):
+        os.environ["GBPCLI_MYMACHINES"] = "this that the other"
+        argv = []
+
+        parser = build_parser()
+        args = parser.parse_args(argv)
+
+        self.assertEqual(args.my_machines, "this that the other")
