@@ -8,7 +8,7 @@ from unittest import mock
 from gbpcli import queries
 from gbpcli.subcommands.notes import handler as create_note
 
-from . import LOCAL_TIMEZONE, TestCase, mock_print
+from . import LOCAL_TIMEZONE, TestCase
 
 MODULE = "gbpcli.subcommands.notes"
 NOTE = "Hello world\n"
@@ -42,7 +42,7 @@ class NotesTestCase(TestCase):
         with mock.patch(f"{MODULE}.sys.stdin.isatty", return_value=True):
             with mock.patch(f"{MODULE}.subprocess.run", wraps=editor) as run:
                 with mock.patch.dict(os.environ, {"EDITOR": "foo"}, clear=True):
-                    status = create_note(self.args, self.gbp, self.console)
+                    status = create_note(self.args, self.gbp, self.console, self.errorf)
 
         self.assertEqual(status, 0)
         self.assert_create_note()
@@ -56,7 +56,7 @@ class NotesTestCase(TestCase):
         with mock.patch(f"{MODULE}.sys.stdin.isatty", return_value=True):
             with mock.patch(f"{MODULE}.subprocess.run", wraps=editor) as run:
                 with mock.patch.dict(os.environ, {"VISUAL": "foo"}, clear=True):
-                    status = create_note(self.args, self.gbp, self.console)
+                    status = create_note(self.args, self.gbp, self.console, self.errorf)
 
         self.assertEqual(status, 1)
         self.assertEqual(self.gbp.session.post.call_count, 1)
@@ -68,14 +68,14 @@ class NotesTestCase(TestCase):
         with mock.patch(f"{MODULE}.sys.stdin.isatty", return_value=True):
             with mock.patch.dict(os.environ, {}, clear=True):
                 with mock.patch(f"{MODULE}.sys.stdin.read", return_value=NOTE):
-                    status = create_note(self.args, self.gbp, self.console)
+                    status = create_note(self.args, self.gbp, self.console, self.errorf)
 
         self.assertEqual(status, 0)
         self.assert_create_note()
 
     def test_delete_deletes_note(self):
         self.args.delete = True
-        create_note(self.args, self.gbp, self.console)
+        create_note(self.args, self.gbp, self.console, self.errorf)
 
         self.assert_create_note(note=None)
 
@@ -85,28 +85,26 @@ class NotesTestCase(TestCase):
 
         with mock.patch(f"{MODULE}.sys.stdin.isatty", return_value=False):
             with mock.patch(f"{MODULE}.sys.stdin.read", return_value=NOTE):
-                create_note(self.args, self.gbp, self.console)
+                create_note(self.args, self.gbp, self.console, self.errorf)
 
         self.assert_create_note()
 
-    @mock_print(MODULE)
-    def test_should_print_error_when_build_does_not_exist(self, print_mock):
+    def test_should_print_error_when_build_does_not_exist(self):
         self.make_response(None)
         self.make_response({"data": {"build": None}})
 
-        status = create_note(self.args, self.gbp, self.console)
+        status = create_note(self.args, self.gbp, self.console, self.errorf)
 
         self.assertEqual(status, 1)
-        self.assertEqual(print_mock.stderr.getvalue(), "Build not found\n")
+        self.assertEqual(self.errorf.getvalue(), "Build not found\n")
 
-    @mock_print("gbpcli.utils")
-    def test_should_print_error_when_invalid_number_given(self, print_mock):
+    def test_should_print_error_when_invalid_number_given(self):
         self.args.number = "foo"
 
         with self.assertRaises(SystemExit):
-            create_note(self.args, self.gbp, self.console)
+            create_note(self.args, self.gbp, self.console, self.errorf)
 
-        self.assertEqual(print_mock.stderr.getvalue(), "Invalid build ID: foo\n")
+        self.assertEqual(self.errorf.getvalue(), "Invalid build ID: foo\n")
 
     def test_search_notes(self):
         self.args.search = True
@@ -114,24 +112,23 @@ class NotesTestCase(TestCase):
         self.make_response(None)
         self.make_response("search_notes.json")
 
-        status = create_note(self.args, self.gbp, self.console)
+        status = create_note(self.args, self.gbp, self.console, self.errorf)
 
         self.assertEqual(status, 0)
         self.assert_graphql(queries.search_notes, machine="lighthouse", key="foo")
         self.assertEqual(self.console.getvalue(), EXPECTED_SEARCH_OUTPUT)
 
-    @mock_print(MODULE)
-    def test_search_no_matches_found(self, print_mock):
+    def test_search_no_matches_found(self):
         self.args.search = True
         self.args.number = "python"
         self.make_response(None)
         self.make_response({"data": {"searchNotes": []}})
 
-        status = create_note(self.args, self.gbp, self.console)
+        status = create_note(self.args, self.gbp, self.console, self.errorf)
 
         self.assertEqual(status, 1)
         self.assert_graphql(queries.search_notes, machine="lighthouse", key="python")
-        self.assertEqual(print_mock.stderr.getvalue(), "No matches found\n")
+        self.assertEqual(self.errorf.getvalue(), "No matches found\n")
 
 
 def fake_editor(text=NOTE, returncode=0):
